==============
PD DB Wrangler
==============


.. image:: https://img.shields.io/pypi/v/pd_db_wrangler.svg
        :target: https://pypi.python.org/pypi/pd_db_wrangler

.. image:: https://img.shields.io/travis/kellerjustin/pd_db_wrangler.svg
        :target: https://travis-ci.com/kellerjustin/pd_db_wrangler

.. image:: https://readthedocs.org/projects/pd-db-wrangler/badge/?version=latest
        :target: https://pd-db-wrangler.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Pandas database helper library


* Free software: MIT license
* Documentation: https://pd-db-wrangler.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
